[llvm-commits] CVS: llvm/include/llvm/Transforms/Scalar.h

Michael Brukman brukman at cs.uiuc.edu
Tue May 20 16:02:11 PDT 2003


Changes in directory llvm/include/llvm/Transforms:

Scalar.h updated: 1.15 -> 1.16

---
Log message:

Hopefully, the final fix for `[Pp]ropogate'.


---
Diffs of the changes:

Index: llvm/include/llvm/Transforms/Scalar.h
diff -u llvm/include/llvm/Transforms/Scalar.h:1.15 llvm/include/llvm/Transforms/Scalar.h:1.16
--- llvm/include/llvm/Transforms/Scalar.h:1.15	Wed Apr 23 11:24:19 2003
+++ llvm/include/llvm/Transforms/Scalar.h	Tue May 20 16:01:09 2003
@@ -15,14 +15,14 @@
 
 //===----------------------------------------------------------------------===//
 //
 // Constant Propogation Pass - A worklist driven constant propogation pass
 //
-Pass *createConstantPropogationPass();
+Pass *createConstantPropagationPass();
 
 
 //===----------------------------------------------------------------------===//
 //
 // Sparse Conditional Constant Propogation Pass
 //
 Pass *createSCCPPass();
 
@@ -152,7 +152,7 @@
 //===----------------------------------------------------------------------===//
 //
 // This pass reassociates commutative expressions in an order that is designed
 // to promote better constant propogation, GCSE, LICM, PRE...
 //
 // For example:  4 + (x + 5)  ->  x + (4 + 5)
 //
@@ -15,14 +15,14 @@
 //===----------------------------------------------------------------------===//
 //
-// Constant Propogation Pass - A worklist driven constant propogation pass
+// Constant Propagation Pass - A worklist driven constant propagation pass
 //
@@ -15,14 +15,14 @@
 //===----------------------------------------------------------------------===//
 //
-// Sparse Conditional Constant Propogation Pass
+// Sparse Conditional Constant Propagation Pass
 //
 Pass *createSCCPPass();
@@ -152,7 +152,7 @@
 //
 // This pass reassociates commutative expressions in an order that is designed
-// to promote better constant propogation, GCSE, LICM, PRE...
+// to promote better constant propagation, GCSE, LICM, PRE...
 //
 // For example:  4 + (x + 5)  ->  x + (4 + 5)





More information about the llvm-commits mailing list